Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(24)

Unified Diff: chrome/app/breakpad_linux.cc

Issue 10982049: Roll DEPS for Breakpad r1020:1050. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « DEPS ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/app/breakpad_linux.cc
===================================================================
--- chrome/app/breakpad_linux.cc (revision 158826)
+++ chrome/app/breakpad_linux.cc (working copy)
@@ -56,7 +56,7 @@
#endif
#if defined(ADDRESS_SANITIZER)
-#include <ucontext.h> // for getcontext().
+#include <ucontext.h> // for getcontext().
#endif
#if defined(OS_ANDROID)
@@ -142,7 +142,7 @@
return len;
}
// uint64_t version of my_itos() from
// breakpad/src/common/linux/linux_libc_support.h. Convert a non-negative
// integer to a string (not null-terminated).
void my_uint64tos(char* output, uint64_t i, unsigned i_len) {
@@ -304,8 +304,8 @@
while (msg_length) {
char num[16];
- const unsigned num_len = my_int_len(++i);
- my_itos(num, i, num_len);
+ const unsigned num_len = my_uint_len(++i);
+ my_uitos(num, i, num_len);
size_t chunk_len = std::min(chunk_size, msg_length);
@@ -685,14 +685,14 @@
void HandleCrashDump(const BreakpadInfo& info) {
int dumpfd;
size_t dump_size;
- uint8_t *dump_data;
+ uint8_t* dump_data;
google_breakpad::PageAllocator allocator;
LoadDataFromFile(allocator, info, info.filename,
&dumpfd, &dump_data, &dump_size);
#if defined(ADDRESS_SANITIZER)
int logfd;
size_t log_size;
- uint8_t *log_data;
+ uint8_t* log_data;
// Load the AddressSanitizer log into log_data.
LoadDataFromFile(allocator, info, info.log_filename,
&logfd, &log_data, &log_size);
@@ -142,7 +142,7 @@
return len;
}
-// uint64_t version of my_itos() from
+// uint64_t version of my_uitos() from
// breakpad/src/common/linux/linux_libc_support.h. Convert a non-negative
// integer to a string (not null-terminated).
« no previous file with comments | « DEPS ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698